@@ -28,3 +28,11 @@ class NoChangesToCommitError(Exception):
 
 class ChangesNotCommitedError(Exception):
     pass
+
+
+class ProjectValidationError(Exception):
+    def __init__(self, errors: list[str]):
+        Exception.__init__(
+            self, "%s errors occurred during load of project" % len(errors)
+        )
+        self.errors: list[str] = errors
