@@ -375,6 +375,13 @@ class ObjectStorageContext(ObjectStorageContextFileMixin):
         if existingItem is not None:
             raise NonUniqueNameError(f"Key {itemKey} already exists")
 
+    @abstractmethod
+    def prepareWorkingBranch(self) -> None:
+        """Prepare working branch
+        Create the working branch from the currently checked out branch
+        """
+        raise NotImplementedError()
+
     @abstractmethod
     def load(self) -> None:
         """Load
@@ -382,6 +389,7 @@ class ObjectStorageContext(ObjectStorageContextFileMixin):
         Call this method after constructing the class, this will load the
         project ready for use.
         """
+        raise NotImplementedError()
 
     @property
     @abstractmethod
