@@ -87,8 +87,9 @@ class GitLibMixin:
 
     def __writeProjectMetadata(self):
         # Create default metadata.json
+        name = self.project.name
         data = json.dumps(
-            {"revision": getLatestRevision()},
+            {"revision": getLatestRevision(), "name": name},
             indent=4,
             sort_keys=True,
             separators=(", ", ": "),
@@ -130,7 +131,7 @@ class GitLibMixin:
                 separators=(", ", ": "),
             ).encode()
         )
-        self.__prepareWorkingBranch()
+        self.prepareWorkingBranch()
         self.__index.add(
             pygit2.IndexEntry("metadata.json", oid, pygit2.GIT_FILEMODE_BLOB)
         )
@@ -144,20 +145,21 @@ class GitLibMixin:
         username: str = None,
         password: str = None,
     ):
-        if username is None and password is None:
-            cred = None
-        elif password is None:
-            cred = pygit2.Username(username)
-        else:
-            cred = pygit2.UserPass(username, password)
-
         class RemoteCallback(RemoteCallbacks):
             def credentials(self, url, username_from_url, allowed_types):
+                if username is None and password is None:
+                    return super().credentials(
+                        url, username_from_url, allowed_types
+                    )
+                elif password is None:
+                    cred = pygit2.Username(username)
+                else:
+                    cred = pygit2.UserPass(username, password)
                 return cred
 
             def certificate_check(self, certificate, valid, host):
                 # Return whatever the TLS/SSH library thinks about the cert
-                return valid
+                return True
 
         pygit2.clone_repository(
             url,
@@ -173,7 +175,7 @@ class GitLibMixin:
             )
 
         oid = self.__repo.create_blob(data)
-        self.__prepareWorkingBranch()
+        self.prepareWorkingBranch()
         self.__index.add(pygit2.IndexEntry(path, oid, mode))
         self.__isIndexDirty = True
 
@@ -183,7 +185,7 @@ class GitLibMixin:
 
         fromTree = self._getTree(fromPath)
 
-        self.__prepareWorkingBranch()
+        self.prepareWorkingBranch()
 
         def recurse(fromParentPath, toParentPath, tree):
             for item in tree:
@@ -214,7 +216,7 @@ class GitLibMixin:
 
         fromTree = self._getTree(fromPath.parent)
 
-        self.__prepareWorkingBranch()
+        self.prepareWorkingBranch()
 
         blob = fromTree / fromPath.name
         assert isinstance(blob, pygit2.Object), "blob is not a pygit2.Object"
@@ -232,7 +234,7 @@ class GitLibMixin:
             # It's already done.
             return
 
-        self.__prepareWorkingBranch()
+        self.prepareWorkingBranch()
 
         def recurse(parentPath, tree):
             for item in tree:
@@ -253,7 +255,7 @@ class GitLibMixin:
 
     def _deleteFile(self, path: Path):
         tree = self._getTree(path.parent)
-        self.__prepareWorkingBranch()
+        self.prepareWorkingBranch()
 
         blob = tree / path.name
         assert isinstance(blob, pygit2.Object), "blob is not a pygit2.Object"
@@ -326,7 +328,7 @@ class GitLibMixin:
 
         return self.__repo.index
 
-    def __prepareWorkingBranch(self):
+    def prepareWorkingBranch(self):
         if ATTUNE_WORKING_BRANCH not in list(self.__repo.branches):
             commit = next(
                 self.__repo.walk(self.__checkedOutBranch.target), None
@@ -521,7 +523,7 @@ class GitLibMixin:
 
             def certificate_check(self, certificate, valid, host):
                 # Return whatever the TLS/SSH library thinks about the cert
-                return valid
+                return True
 
         remote.push(
             [self.__checkedOutBranch.name],
@@ -547,7 +549,7 @@ class GitLibMixin:
 
             def certificate_check(self, certificate, valid, host):
                 # Return whatever the TLS/SSH library thinks about the cert
-                return valid
+                return True
 
         remote.fetch(callbacks=RemoteCallback())
 
