@@ -1,6 +1,5 @@
 import logging
 import os
-import sqlite3
 
 from alembic.config import Config
 from alembic.runtime.migration import MigrationContext
@@ -16,19 +15,14 @@ logger = logging.getLogger(__name__)
 def runMigrationsForStorageContext(storageContext: ObjectStorageContext):
     currentRev = storageContext.getRevision()
 
-    # Create a temporary database file
-    db = sqlite3.connect("")
-    cur = db.cursor()
-    cur.execute("CREATE TABLE alembic_version(version_num varchar)")
-    # What if someone sets currentRev to "Robert'); DROP TABLE users;--" ?
-    cur.execute(
+    # Create a temporary database file and an engine to it
+    engine = create_engine("sqlite:///")
+    # Load the alembic_version table and insert the project value into it
+    engine.execute("CREATE TABLE alembic_version(version_num varchar)")
+    engine.execute(
         f"INSERT INTO alembic_version (version_num) VALUES ('{currentRev}')"
     )
-    db.commit()
-
-    # Since sqlite3 can have only one memory DB per thread, this `:memory:` DB
-    # will be the same as the one created previously
-    engine = create_engine("sqlite:///")
+    # We don't seem to need a commit
 
     # Load the migration scripts and
     codeDir = os.path.dirname(os.path.realpath(__file__))
@@ -55,6 +49,7 @@ def runMigrationsForStorageContext(storageContext: ObjectStorageContext):
 
         if currentRev != latestRev:
             logger.info("Running migrations for Project API")
+            storageContext.prepareWorkingBranch()
             context.run_migrations(storageContext=storageContext)
             storageContext.setRevision(latestRev)
             storageContext.squashAndMergeWorking(
